# pyQSC
Python implementation of the Quasisymmetric Stellarator Construction method

This code implements the equations derived by Garren and Boozer (1991) for MHD equilibrium near the magnetic axis.

View the [main documentation here](https://landreman.github.io/pyQSC/)